@@ -32,7 +32,8 @@ class LM:
                  use_auth_token: bool = False,
                  max_length: int = None,
                  device: str = None,
-                 num_gpus: int = None):
+                 num_gpus: int = None,
+                 torch_dtype=None):
         """ Language Model.
 
         @param model: Model alias or path to local model file.
@@ -48,8 +49,13 @@ class LM:
             model, local_files_only=local_files_only, use_auth_token=use_auth_token)
         self.config = transformers.AutoConfig.from_pretrained(
             model, local_files_only=local_files_only, use_auth_token=use_auth_token)
-        self.model = transformers.AutoModelForCausalLM.from_pretrained(
-            model, config=self.config, local_files_only=local_files_only, use_auth_token=use_auth_token)
+        if torch_dtype is None:
+            self.model = transformers.AutoModelForCausalLM.from_pretrained(
+                model, config=self.config, local_files_only=local_files_only, use_auth_token=use_auth_token)
+        else:
+            self.model = transformers.AutoModelForCausalLM.from_pretrained(
+                model, config=self.config, local_files_only=local_files_only, use_auth_token=use_auth_token,
+                torch_dtype=torch_dtype)
         if self.tokenizer.pad_token is None:
             self.tokenizer.pad_token = "<<PAD>>"
         if max_length is None:
